@@ -19,8 +19,10 @@
 #'
 #' @format NULL
 #'
+#' @importFrom GCPtools gcloud_access_token
+#'
 #' @examples
-#' library(AnVILGCP)
+#' library(GCPtools)
 #' if (gcloud_exists())
 #'     Leonardo()
 #'
@@ -28,9 +30,7 @@
 Leonardo <-
     function()
 {
-    if (!requireNamespace("AnVILGCP", quietly = TRUE))
-        stop("Install 'AnVILGCP' to use 'Leonardo()'", call. = FALSE)
-    access_token <- AnVILGCP::gcloud_access_token("leonardo")
+    access_token <- gcloud_access_token("leonardo")
     api_header <- c(
         Authorization = paste("Bearer", access_token),
         Referer = "https://leonardo.dsde-prod.broadinstitute.org"
